#!/bin/sh
export PATH='/build/haskell-tasty-discover/src/tasty-discover-4.2.2/dist/build/tasty-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
'/usr/bin/ghc-pkg' 'unregister' '--force' '--global' 'tasty-discover-4.2.2' "$@"
